@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2008, Nokia
  *
@@ -92,70 +91,6 @@ strcasestr (const gchar *haystack,
 
 #endif /* HAVE_STRCASESTR */
 
-/* NOTE: This function was stolen from GLib 2.18.x. Since upstream and
- * the Maemo branch don't have this in circulation yet, we have copied
- * it here. This can be removed an replaced with
- * g_file_make_directory_with_parents() when we get it. -mr
- */
-static gboolean
-make_directory_with_parents (GFile         *file,
-                             GCancellable  *cancellable,
-                             GError       **error)
-{
-	gboolean result;
-	GFile *parent_file, *work_file;
-	GList *list = NULL, *l;
-	GError *my_error = NULL;
-
-	if (g_cancellable_set_error_if_cancelled (cancellable, error))
-		return FALSE;
-
-	result = g_file_make_directory (file, cancellable, &my_error);
-	if (result || my_error->code != G_IO_ERROR_NOT_FOUND)
-		{
-			if (my_error)
-				g_propagate_error (error, my_error);
-			return result;
-		}
-
-	work_file = file;
-
-	while (!result && my_error->code == G_IO_ERROR_NOT_FOUND)
-		{
-			g_clear_error (&my_error);
-
-			parent_file = g_file_get_parent (work_file);
-			if (parent_file == NULL)
-				break;
-			result = g_file_make_directory (parent_file, cancellable, &my_error);
-
-			if (!result && my_error->code == G_IO_ERROR_NOT_FOUND)
-				list = g_list_prepend (list, parent_file);
-
-			work_file = parent_file;
-		}
-
-	for (l = list; result && l; l = l->next)
-		{
-			result = g_file_make_directory ((GFile *) l->data, cancellable, &my_error);
-		}
-
-	/* Clean up */
-	while (list != NULL)
-		{
-			g_object_unref ((GFile *) list->data);
-			list = g_list_remove (list, list->data);
-		}
-
-	if (!result)
-		{
-			g_propagate_error (error, my_error);
-			return result;
-		}
-
-	return g_file_make_directory (file, cancellable, error);
-}
-
 static gboolean
 albumart_strip_find_next_block (const gchar    *original,
                                 const gunichar  open_char,
@@ -738,7 +673,7 @@ albumart_copy_to_local (TrackerStorage *hal,
 			GFile *dirf;
 
 			dirf = g_file_get_parent (local_file);
-			make_directory_with_parents (dirf, NULL, NULL);
+			g_file_make_directory_with_parents (dirf, NULL, NULL);
 			g_object_unref (dirf);
 
 			g_debug ("Copying album art from:'%s' to:'%s'",
